@@ -92,14 +92,14 @@ displayIV<-function(dset,col="xyz",resp="y",adjFactor=0.5,bins=10)
 
   }
 
-  df_tot <- d %>%  dplyr::group_by_(naml) %>% dplyr::summarise(tot=n())
+  df_tot <- d %>%  dplyr::group_by_(naml) %>% dplyr::summarise(tot=dplyr::n())
 
   df_tot<-as.data.frame(df_tot)
   df_tot$tot_pct<-df_tot[,2]/sum(df_tot[,2])
 
   val<-1
   filter_criteria<-lazyeval::interp(~y==x, .values = list(y=as.name(resp),x=val))
-  df_one <- d %>%  dplyr::filter(d[[resp]]==1) %>% dplyr::group_by_(naml) %>% dplyr::summarise(bad=n())
+  df_one <- d %>%  dplyr::filter(d[[resp]]==1) %>% dplyr::group_by_(naml) %>% dplyr::summarise(bad=dplyr::n())
 
   df_one<-as.data.frame(df_one)
 
@@ -109,7 +109,7 @@ displayIV<-function(dset,col="xyz",resp="y",adjFactor=0.5,bins=10)
 
   val<-0
   filter_criteria<-lazyeval::interp(~y==x, .values = list(y=as.name(resp),x=val))
-  df_zero <- d %>%  dplyr::filter(d[[resp]]==0) %>% dplyr::group_by_(naml) %>% dplyr::summarise(good=n())
+  df_zero <- d %>%  dplyr::filter(d[[resp]]==0) %>% dplyr::group_by_(naml) %>% dplyr::summarise(good=dplyr::n())
 
   df_zero<-as.data.frame(df_zero)
 
