@@ -104,16 +104,16 @@ numericToCategorical<-function(dset,col="job",resp="y",bins=10,adjFactor=0.5)
   l<-ncol(d)
   naml<-names(d[l])
 
-  df_tot <- d %>%  dplyr::group_by_(naml) %>% dplyr::summarise(tot=n())
+  df_tot <- d %>%  dplyr::group_by_(naml) %>% dplyr::summarise(tot=dplyr::n())
   df_tot<-as.data.frame(df_tot)
 
-  df_one <- d %>%  dplyr::filter(d[[resp]]==1) %>% dplyr::group_by_(naml) %>% dplyr::summarise(bad=n())
+  df_one <- d %>%  dplyr::filter(d[[resp]]==1) %>% dplyr::group_by_(naml) %>% dplyr::summarise(bad=dplyr::n())
 
   df_one<-as.data.frame(df_one)
 
   one_rate <- (df_one[,2]/sum(df_one[,2]))*100
 
-  df_zero <- d %>%  dplyr::filter(d[[resp]]==0) %>% dplyr::group_by_(naml) %>% dplyr::summarise(good=n())
+  df_zero <- d %>%  dplyr::filter(d[[resp]]==0) %>% dplyr::group_by_(naml) %>% dplyr::summarise(good=dplyr::n())
 
   df_zero<-as.data.frame(df_zero)
 
@@ -204,5 +204,3 @@ numericToCategorical<-function(dset,col="job",resp="y",bins=10,adjFactor=0.5)
   return(mnlist)
 
 }
-
-
